@@ -1,10 +1,10 @@
 #
 # act.py - DITrack 'act' command
 #
-# Copyright (c) 2006-2007 The DITrack Project, www.ditrack.org.
+# Copyright (c) 2006-2008 The DITrack Project, www.ditrack.org.
 #
-# $Id: act.py 2279 2007-10-24 05:41:53Z vss $
-# $HeadURL: https://127.0.0.1/ditrack/src/tags/0.7/DITrack/Command/act.py $
+# $Id: act.py 2516 2008-05-26 14:25:52Z gli $
+# $HeadURL: https://svn.xiolabs.com/ditrack/src/tags/0.8/DITrack/Command/act.py $
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -30,6 +30,7 @@
 
 import copy
 import email
+import email.Message
 import os
 import sys
 
@@ -130,6 +131,18 @@ class _Driver:
             except DITrack.DB.Exceptions.InconsistentActionError, msg:
                 raise _InconsistencyError(id, msg)
 
+    def _change_issues_header(self, header):
+        """
+        Update (or add) a single header of/to all issues. The header name and
+        its new value are passed in HEADER, separated by '='.
+
+        Raises ValueError if HEADER couldn't be parsed out.
+        """
+        k, v = header.split("=", 1)
+        for issue in self._issues.itervalues():
+            # XXX: should probably use internal method like replace_header().
+            issue.info[k] = v
+
     def run(self):
         """
         Runs the driver. Returns a sorted list of issue numbers (XXX) to try
@@ -225,6 +238,14 @@ class _CmdlineDriver(_Driver):
                 except _InconsistencyError, e:
                     return self._invalid_action(action, e.issue_id, e.message)
 
+            elif action == "change-header":
+                try:
+                    self._change_issues_header(arg)
+                except ValueError:
+                    DITrack.Util.common.err(
+                        "'change-header' requires 'header=value' argument"
+                    )
+
             else:
                 DITrack.Util.common.err("Invalid action: %s" % action)
 
@@ -327,6 +348,102 @@ class _InteractiveDriver(_Driver):
                 # Go straight to the main menu from here
                 return
 
+    def _reply_comment(self):
+
+        assert self._single_issue
+
+        # XXX: shouldn't a 'human-redable' representation of dates be a member
+        # of the Comment class?
+        def rm_timestamp(text):
+            return text.split(" ", 1)[1]
+
+        issue = self._issues[self._issue_numbers[0]]
+
+        # Get only "firm" comments
+        comments = issue.comments(local=False)
+
+        # Creating comment choice menu
+        mi_reply_abort = DITrack.UI.MenuItem("a", "abort")
+
+        mi_reply_comments = [
+            DITrack.UI.MenuItem(
+                0,
+                "original description by %s, %s" % (
+                    issue.info["Opened-by"],
+                    rm_timestamp(issue.info["Opened-on"])
+                )
+            )
+        ]
+
+        for (id, c) in comments[1:]:
+            mi_reply_comments.append(
+                DITrack.UI.MenuItem(
+                    int(id),
+                    "comment #%s by %s, %s" % (
+                        id, c.added_by, rm_timestamp(c.added_on)
+                    )
+                )
+            )
+
+        reply_menu = DITrack.UI.Menu(
+            "Choose a comment to reply to",
+            [mi_reply_abort] + mi_reply_comments
+        )
+
+        comment_id = None
+
+        while comment_id is None:
+            r = reply_menu.run()
+
+            if r == mi_reply_abort:
+                break
+            else:
+                # Comment id to reply to
+                id = "%d" % r.key          
+                c = issue[id]
+
+                sys.stdout.write(
+                    "\n======\n"
+                    "\nComment #%s by %s, %s\n\n" % (
+                        id,
+                        c.added_by,
+                        rm_timestamp(c.added_on)
+                    )
+                )
+                sys.stdout.write("".join(c.header_as_strings()))
+                sys.stdout.write("\n" + c.text + "\n======\n")
+
+                ti_confirmation = DITrack.UI.TextInput(
+                    "Is this the comment you'd like to reply to (y/n)?"
+                )
+
+                while 1:
+                    choice = ti_confirmation.run()
+                    if choice == "y":
+                        comment_id = id
+                        break
+                    elif choice == "n":
+                        break
+
+        if comment_id is not None:
+            c = issue[comment_id]
+
+            def _quote_string(str):
+                if str and (str[0] != ">"):
+                    return "> " + str
+                else:
+                    return ">" + str
+
+            self.comment_text = DITrack.Edit.edit_text(
+                self._globals,
+                "\nQuoting c#%s by %s, %s\n\n%s" % (
+                    id,
+                    c.added_by,
+                    rm_timestamp(c.added_on),
+                    "\n".join(map(_quote_string, c.text.split("\n")))
+                )
+            )
+
     def run(self):
         """
         If changes are to be saved (see the base class method description),
@@ -344,6 +461,7 @@ class _InteractiveDriver(_Driver):
         mi_quit = DITrack.UI.MenuItem("q", "quit, saving changes")
         mi_reassign = DITrack.UI.MenuItem("o", "reassign the issue owner")
         mi_reopen = DITrack.UI.MenuItem("r", "reopen the issue")
+        mi_reply = DITrack.UI.MenuItem("re", "reply to a comment")
 
         menu = DITrack.UI.Menu("Choose an action for the issue(s)",
             [
@@ -355,7 +473,8 @@ class _InteractiveDriver(_Driver):
             mi_edit_text,
             mi_quit,
             mi_reassign,
-            mi_reopen
+            mi_reopen,
+            mi_reply
             ])
 
         save_changes = False
@@ -373,7 +492,10 @@ class _InteractiveDriver(_Driver):
 
             mi_reopen.enabled = filter(
                 lambda x: x.info["Status"] == "closed",
-                self._issues.itervalues())
+                self._issues.itervalues()
+            )
+
+            mi_reply.enabled = self._single_issue and self.comment_text == ""
 
             sys.stdout.write("\nActing on:\n")
 
@@ -454,14 +576,19 @@ class _InteractiveDriver(_Driver):
 
                 info = email.Message.Message()
 
-                for k, v in self._issues[id].info.iteritems():
-                    info.add_header(k, v)
+                keys = self._issues[id].info.keys()
+                keys.sort()
+                for k in keys:
+                    info.add_header(k, self._issues[id].info[k])
 
                 header = DITrack.Edit.edit_text(
                     self._globals, info.as_string()
                 )
 
-                self._issues[id].info = email.message_from_string(header)
+                self._issues[id].info = {}
+                new_info = email.message_from_string(header)
+                for h in new_info.keys():
+                    self._issues[id].info[h] = new_info[h]
 
             elif r == mi_edit_text:
                 self.comment_text = DITrack.Edit.edit_text(self._globals,
@@ -493,6 +620,9 @@ class _InteractiveDriver(_Driver):
             elif r == mi_reopen:
                 self._reopen_issues()
 
+            elif r == mi_reply:
+                self._reply_comment()
+
             else:
                 raise NotImplementedError
 
@@ -512,6 +642,10 @@ usage: %s ISSUENUM [ISSUENUM...]""" % canonical_name
     description_ps = """
 ACTIONLIST is a comma-separated list of one of more of the following actions:
 
+    change-header:HEADER=VALUE
+        - add/update issue(s) header HEADER with specified value VALUE;
+        omitting VALUE removes the header.
+
     close:{dropped, fixed, invalid}
         - close the issue(s) with specified resolution.
 
