@@ -3,8 +3,8 @@
 #
 # Copyright (c) 2006-2007 The DITrack Project, www.ditrack.org.
 #
-# $Id: list.py 2190 2007-10-15 22:31:17Z vss $
-# $HeadURL: https://127.0.0.1/ditrack/src/tags/0.7/DITrack/Command/list.py $
+# $Id: list.py 2390 2007-11-24 17:07:13Z oleg $
+# $HeadURL: https://svn.xiolabs.com/ditrack/src/tags/0.8/DITrack/Command/list.py $
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -74,8 +74,10 @@ usage: %s [FILTER...]""" % canonical_name
         for id, issue in issues:
             xo.writer.opentag("issue", { "id": str(id) }, nl=True)
 
-            for k, v in issue.info.items():
-                xo.writer.tag_enclose(k, {}, v, nl=True, indent=2)
+            issue_keys = issue.info.keys()
+            issue_keys.sort()
+            for k in issue_keys:
+                xo.writer.tag_enclose(k, {}, issue.info[k], nl=True, indent=2)
 
             xo.writer.closetag("issue")
             xo.writer.text("\n\n")
