@@ -3,8 +3,8 @@
 #
 # Copyright (c) 2006-2007 The DITrack Project, www.ditrack.org.
 #
-# $Id: Common.py 2260 2007-10-23 11:11:01Z gli $
-# $HeadURL: https://127.0.0.1/ditrack/src/tags/0.7/DITrack/DB/Common.py $
+# $Id: Common.py 2439 2008-01-21 16:17:21Z gli $
+# $HeadURL: https://svn.xiolabs.com/ditrack/src/tags/0.8/DITrack/DB/Common.py $
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -34,6 +34,7 @@ import pprint
 import re
 import string
 import errno
+import shelve
 import sys
 
 # DITrack modules
@@ -51,7 +52,10 @@ import DITrack.Util.Locking
 VERSION_PROP = "ditrack:format"
 
 # Current database format version.
-FORMAT_VERSION = "3"
+FORMAT_VERSION = "4"
+
+# File with database format version
+DATABASE_VERSION_FILE = "format"
 
 # Local modifications area directory and file name
 LOCAL_DT_DIR = ".ditrack"
@@ -98,6 +102,20 @@ def next_entity_name(names):
 
     return res
 
+def open_local_dt_shelve(path, filename):
+    """
+    Opens a shelve in local DITrack directory (LOCAL_DT_DIR) which is created
+    as needed. The name of the shelve to open is passed in FILENAME. Returns
+    the shelve handle.
+    """
+
+    datadir = os.path.join(path, LOCAL_DT_DIR)
+
+    if not os.path.exists(datadir):
+        os.mkdir(datadir, 0755)
+
+    return shelve.open(os.path.join(datadir, filename))
+
 #
 # Classes
 #
@@ -137,7 +155,11 @@ class Database:
             raise DITrack.DB.Exceptions.NotDirectoryError
 
         # Get database version
-        v = DITrack.SVN.propget(VERSION_PROP, path, svn_path)
+        try:
+            v = open(os.path.join(path, DATABASE_VERSION_FILE), 
+                "r").readline().split()[0]
+        except IOError:
+            v = None
 
         if not v or not len(v):
             raise DITrack.DB.Exceptions.NotDatabaseError
@@ -560,6 +582,8 @@ class Filter:
             if len(condition) != 3:
                 raise DITrack.DB.Exceptions.FilterExpressionError(c)
 
+            if condition['value'] == '""' or condition['value'] == "''":
+                condition['value'] = ""
             # Perform substitutions.
             t = DITrack.ThirdParty.Python.string.Template(condition['value'])
             try:
@@ -580,13 +604,18 @@ class Filter:
             assert len(c) == 3
 
             if c['param'] not in issue.info:
-                return False
+                if c['value'] != "":
+                    return False
+                else:
+                    info_value = ""
+            else:
+                info_value = issue.info[c['param']]
 
             if c['condition'] == "=":
-                if issue.info[c['param']] != c['value']:
+                if info_value != c['value']:
                     return False
             elif c['condition'] == "!=":
-                if issue.info[c['param']] == c['value']:
+                if info_value == c['value']:
                     return False
             else:
                 raise DITrack.DB.Exceptions.NotImplemented, c['condition']
