@@ -3,8 +3,8 @@
 #
 # Copyright (c) 2006-2007 The DITrack Project, www.ditrack.org.
 #
-# $Id: Issue.py 2275 2007-10-24 00:30:05Z vss $
-# $HeadURL: https://127.0.0.1/ditrack/src/tags/0.7/DITrack/DB/Issue.py $
+# $Id: Issue.py 2605 2008-06-23 03:07:37Z vss $
+# $HeadURL: https://svn.xiolabs.com/ditrack/src/tags/0.8/DITrack/DB/Issue.py $
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -397,6 +397,16 @@ class Issue:
 
         return map(lambda k: "%s: %s%s" % (k, self.info[k], terminator), keys)
 
+    def is_up_to_date(self, path):
+        """
+        Check if the issue is up to date with respect to its on-disk
+        representation at PATH (should point to the issue directory).
+        """
+
+        n = int(self.firm_names[-1])
+        fname = os.path.join(path, "comment%d" % (n + 1))
+
+        return not os.path.exists(fname)
 
     def load(cls, path):
         """
@@ -573,37 +583,6 @@ class Comment:
     A representation of a comment record.
     """
 
-    def attachments_added(self):
-        """
-        Returns a list of added attachments for this comment or None if there 
-        is none. The returned list is a list of AttachedFile objects.
-        """
-        if self.attachments_changed():
-            return self._attachment_delta["added"]
-
-    def attachments_changed(self):
-        """
-        Returns True if this comment makes any changes to the attached files.
-
-        Assertions will fail if the data is inconsistent in any way.
-        """
-        if self._attachment_delta is None:
-            return False
-
-        assert "added" in self._attachment_delta
-        assert "removed" in self._attachment_delta
-
-        return self._attachment_delta["added"] or \
-            self._attachment_delta["removed"]
-
-    def attachments_removed(self):
-        """
-        Returns a list of removed attachments for this comment or None if there 
-        is none. The returned list is a list of AttachedFile objects.
-        """
-        if self.attachments_changed():
-            return self._attachment_delta["removed"]
-
     def apply_delta(self, info, attachments):
         """
         Applies own delta to the info dictionary INFO.
@@ -667,6 +646,37 @@ class Comment:
         else:
             DEBUG("Attachment delta is empty")
 
+    def attachments_added(self):
+        """
+        Returns a list of added attachments for this comment or None if there 
+        is none. The returned list is a list of AttachedFile objects.
+        """
+        if self.attachments_changed():
+            return self._attachment_delta["added"]
+
+    def attachments_changed(self):
+        """
+        Returns True if this comment makes any changes to the attached files.
+
+        Assertions will fail if the data is inconsistent in any way.
+        """
+        if self._attachment_delta is None:
+            return False
+
+        assert "added" in self._attachment_delta
+        assert "removed" in self._attachment_delta
+
+        return self._attachment_delta["added"] or \
+            self._attachment_delta["removed"]
+
+    def attachments_removed(self):
+        """
+        Returns a list of removed attachments for this comment or None if there 
+        is none. The returned list is a list of AttachedFile objects.
+        """
+        if self.attachments_changed():
+            return self._attachment_delta["removed"]
+
     def create(cls, text, added_on, added_by, delta, logmsg="",
         attachment_delta=None):
 
