@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 #
-# upgrade-0.5-db.py - utility to convert database format from version 2 (0.5)
-#   to version 3 (0.6)
+# upgrade-0.7-db.py - utility to convert database format from version 3 (0.6,
+# 0.7) to version 4 (0.8)
 #
-# Copyright (c) 2006-2007 The DITrack Project, www.ditrack.org.
+# Copyright (c) 2006-2008 The DITrack Project, www.ditrack.org.
 #
-# $Id: upgrade-0.5-db.py 1954 2007-08-26 20:33:06Z vss $
-# $HeadURL: https://127.0.0.1/ditrack/src/tags/0.7/upgrade-0.5-db.py $
+# $Id: upgrade-0.7-db.py 2520 2008-05-28 06:56:26Z vss $
+# $HeadURL: https://svn.xiolabs.com/ditrack/src/tags/0.8/upgrade-0.7-db.py $
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -35,8 +35,8 @@ import sys
 
 if len(sys.argv) != 2:
     sys.stderr.write("""
-This is a utility to convert DITrack database from format 2 (DITrack version
-0.5) to format 3 (DITrack 0.6).
+This is a utility to convert DITrack database from format 3 (DITrack version
+0.6, 0.7) to format 4 (DITrack 0.8).
 
 Usage:
     %s DBPATH
@@ -49,7 +49,7 @@ dbpath = sys.argv[1]
 
 version = os.popen("svn pg ditrack:format %s" % (dbpath), "r").readline().strip()
 
-if version != "2":
+if version != "3":
     sys.stderr.write("Unsupported database format version: %s" % version)
     sys.exit(1)
 
@@ -60,8 +60,14 @@ default: %(id)-4s %(Owned-by)-8s %(Due-in)-8s %(Status)-6s %(Title)s
 """
 )
 
-os.system("svn ps ditrack:format 3 %s" % (dbpath))
-os.system("svn add %s" % listing_format)
+format=os.path.join(dbpath, "format")
+try:
+    open(format,"w").write("4\n")
+except:
+    sys.stdout.write("Can't initialize database format version file\n")
+    sys.exit(1)
+
+os.system("svn add %s" % (format))
 sys.stdout.write("""
 Database was successully converted
 
